# pysqlcon

A library for object relational mapping using Microsoft SQL Server database.

pysqlcon is a custom ORM specifically made for MSSQL database. It contains functions for connecting to the database, executing raw SQL queries, stored procedures and SQL queries stored in files.

# Dependancies
* pyodbc
* ODBC driver 13 for SQL Server  
